@@ -7,6 +7,9 @@ module Fog
 
     @channels[:debug] = ::STDERR if ENV["DEBUG"]
 
+    # provide an env var with narrower scope in case of namespace conflicts
+    @channels[:debug] = ::STDERR if ENV["FOG_DEBUG"]
+
     def self.[](channel)
       @channels[channel]
     end
