@@ -27,8 +27,8 @@ if Fog.mock?
     :clodo_username                   => "clodo_username",
     :digitalocean_api_key             => "digitalocean_api_key",
     :digitalocean_client_id           => "digitalocean_client_id",
-    :dnsimple_email                   => "dnsimple_email",
-    :dnsimple_password                => "dnsimple_password",
+    :dnsimple_token                   => "dnsimple_token",
+    :dnsimple_account                 => "dnsimple_account",
     :dnsmadeeasy_api_key              => "dnsmadeeasy_api_key",
     :dnsmadeeasy_secret_key           => "dnsmadeeasy_secret_key",
     :glesys_username                  => "glesys_username",
@@ -66,7 +66,6 @@ if Fog.mock?
     :ovirt_url                        => "http://ovirt:8080/api",
     :ovirt_username                   => "admin@internal",
     :ovirt_password                   => "123123",
-    :libvirt_uri                      => "qemu://libvirt/system",
     :rackspace_api_key                => "rackspace_api_key",
     :rackspace_username               => "rackspace_username",
     :riakcs_access_key_id             => "riakcs_access_key_id",
@@ -92,6 +91,9 @@ if Fog.mock?
     :libvirt_username                 => "root",
     :libvirt_password                 => "password",
     :cloudsigma_username              => "csuname",
-    :cloudsigma_password              => "cspass"
+    :cloudsigma_password              => "cspass",
+    :kubevirt_token                   => "[TOKEN]",
+    :kubevirt_hostname                => "localhost",
+    :kubevirt_port                    => "6443"
   }.merge(Fog.credentials)
 end
