@@ -10,22 +10,30 @@ describe "Fog::Compute" do
   describe "#new" do
     module Fog
       module TheRightWay
-        extend Provider
-        service(:compute, "Compute")
+        class Compute
+          def initialize(_args); end
+        end
       end
     end
 
     module Fog
-      module Compute
-        class TheRightWay
-          def initialize(_args); end
-        end
+      module TheRightWay
+        extend Provider
+        service(:compute, "Compute")
       end
     end
 
     it "instantiates an instance of Fog::Compute::<Provider> from the :provider keyword arg" do
       compute = Fog::Compute.new(:provider => :therightway)
-      assert_instance_of(Fog::Compute::TheRightWay, compute)
+      assert_instance_of(Fog::TheRightWay::Compute, compute)
+    end
+
+    module Fog
+      module Compute
+        class TheWrongWay
+          def initialize(_args); end
+        end
+      end
     end
 
     module Fog
@@ -35,37 +43,14 @@ describe "Fog::Compute" do
       end
     end
 
-    module Fog
-      module TheWrongWay
-        class Compute
-          def initialize(_args); end
-        end
-      end
-    end
-
     it "instantiates an instance of Fog::<Provider>::Compute from the :provider keyword arg" do
       compute = Fog::Compute.new(:provider => :thewrongway)
-      assert_instance_of(Fog::TheWrongWay::Compute, compute)
-    end
-
-    module Fog
-      module BothWays
-        extend Provider
-        service(:compute, "Compute")
-      end
+      assert_instance_of(Fog::Compute::TheWrongWay, compute)
     end
 
     module Fog
       module BothWays
         class Compute
-          def initialize(_args); end
-        end
-      end
-    end
-
-    module Fog
-      module Compute
-        class BothWays
           attr_reader :args
           def initialize(args)
             @args = args
@@ -74,10 +59,25 @@ describe "Fog::Compute" do
       end
     end
 
+    module Fog
+      module Compute
+        class BothWays
+          def initialize(_args); end
+        end
+      end
+    end
+
+    module Fog
+      module BothWays
+        extend Provider
+        service(:compute, "Compute")
+      end
+    end
+
     describe "when both Fog::Compute::<Provider> and Fog::<Provider>::Compute exist" do
-      it "prefers Fog::Compute::<Provider>" do
+      it "prefers Fog::<Provider>::Compute" do
         compute = Fog::Compute.new(:provider => :bothways)
-        assert_instance_of(Fog::Compute::BothWays, compute)
+        assert_instance_of(Fog::BothWays::Compute, compute)
       end
     end
 
