@@ -1,4 +1,4 @@
-require 'spec_helper'
+require "spec_helper"
 
 describe Fog::CurrentMachine do
   before do
@@ -19,16 +19,18 @@ describe Fog::CurrentMachine do
 
   describe "ip_address" do
     it "should be thread safe" do
-      Excon.stub({:method => :get, :path => "/"}, {:body => ""})
 
-      (1..10).map {
-        Thread.new { Fog::CurrentMachine.ip_address }
-      }.each{ |t| t.join }
+      (1..10).map do
+        Thread.new do
+          Excon.stub({ :method => :get, :path => "/" }, { :body => "" })
+          Fog::CurrentMachine.ip_address
+        end
+      end.each(&:join)
     end
 
     it "should remove trailing endline characters" do
-      Excon.stub({:method => :get,  :path => "/"}, {:body => "192.168.0.1\n"})
+      Excon.stub({ :method => :get, :path => "/" }, { :body => "192.168.0.1\n" })
       assert_equal "192.168.0.1", Fog::CurrentMachine.ip_address
     end
-  end  
+  end
 end
